@@ -1,15 +1,16 @@
 from linux_profile.base.action import Action
-from linux_profile.base.config import Config
+from linux_profile.base.settings import Settings
 from linux_profile.utils.text import option
 from linux_profile.validators import (
     InputAddPackage,
     InputAddAlias,
     InputAddScript,
-    InputAddFile
+    InputAddFile,
+    InputAddText
 )
 
 
-class Add(Config):
+class Add(Settings):
 
     def setup(self):
         """Defines the functions that are executed each
@@ -17,7 +18,7 @@ class Add(Config):
         """
         self.command = self.__class__.__name__.lower()
         self.action = Action(
-            self.join([self.linuxp_path_config, self.linuxp_file_profile]))
+            str(self.path_profile.joinpath(self.file_profile)))
 
         func = self.join(value=[self.command, self.module], separator="_")
         getattr(self, func, self)()
@@ -82,3 +83,16 @@ class Add(Config):
             module=self.module,
             tag=fields.tag
         )
+
+    def add_text(self):
+        fields = InputAddText(**{
+            "tag": option(text="Tag [default]: "),
+            "name": option(text="Name: ", required=True),
+            "text": option(text="Text: ", required=True),
+            "label": option(text="Label: ")}
+        )
+        self.action._create_item(
+            content=fields.__dict__,
+            module=self.module,
+            tag=fields.tag
+        )
