@@ -1,7 +1,7 @@
-from linux_profile.base.config import Config
+from linux_profile.base.settings import Settings
 
 
-class Execute(Config):
+class Execute(Settings):
 
     def __init__(self, **kwargs) -> None:
         super().__init__(**kwargs)
