@@ -4,6 +4,7 @@ import argparse
 
 from linux_profile.base.command import BaseCommand, Command
 
+from linux_profile.commands.account import Account
 from linux_profile.commands.add import Add
 from linux_profile.commands.config import Config
 from linux_profile.commands.profile import Profile
@@ -59,7 +60,8 @@ class CommandInstall(Command):
                 debug=self.debug,
                 module=self.module,
                 tag=self.tag,
-                item=self.item
+                item=self.item,
+                group=self.group
             )
         )
 
@@ -74,7 +76,8 @@ class CommandUninstall(Command):
                 debug=self.debug,
                 module=self.module,
                 tag=self.tag,
-                item=self.item
+                item=self.item,
+                group=self.group
             )
         )
 
@@ -92,20 +95,40 @@ class CommandList(Command):
         )
 
 
+class CommandAccount(Command):
+
+    def execute(self):
+        """Start"""
+        Account(**self.arguments.__dict__)
+
+
+class BuildCommand:
+
+    base_command = BaseCommand
+
+    def __init__(self) -> None:
+        parser = argparse.ArgumentParser(description='🐧 Linux Profile Management CLI Tool')
+        self.command = self.base_command(parser)
+        self.core_commands()
+        self.command.run()
+
+    def core_commands(self):
+        self.command.cmd_config.set_defaults(exec=CommandConfig)
+        self.command.cmd_profile.set_defaults(exec=CommandProfile)
+        self.command.cmd_add.set_defaults(exec=CommandAdd)
+        self.command.cmd_remove.set_defaults(exec=CommandRemove)
+        self.command.cmd_execute.set_defaults(exec=CommandExecute)
+        self.command.cmd_install.set_defaults(exec=CommandInstall)
+        self.command.cmd_uninstall.set_defaults(exec=CommandUninstall)
+        self.command.cmd_list.set_defaults(exec=CommandList)
+        self.setup()
+
+    def setup(self) -> str:
+        return "Method not Implemented"
+
+
 def main():
-    parser = argparse.ArgumentParser(description='Linux profile management tool')
-    command = BaseCommand(parser)
-
-    command.cmd_config.set_defaults(exec=CommandConfig)
-    command.cmd_profile.set_defaults(exec=CommandProfile)
-    command.cmd_add.set_defaults(exec=CommandAdd)
-    command.cmd_remove.set_defaults(exec=CommandRemove)
-    command.cmd_execute.set_defaults(exec=CommandExecute)
-    command.cmd_install.set_defaults(exec=CommandInstall)
-    command.cmd_uninstall.set_defaults(exec=CommandUninstall)
-    command.cmd_list.set_defaults(exec=CommandList)
-
-    command.run()
+    BuildCommand()
 
 
 if __name__ == '__main__':
