@@ -1,6 +1,36 @@
-from os import popen
+def write_file(
+        content: str,
+        path_file: str,
+        type_file: str = '',
+        mode: str = 'w') -> str:
+    with open(path_file + type_file, mode) as outfile:
+        outfile.write(content)
 
 
+def read_file(
+        path_file: str,
+        type_file: str = '') -> str:
+    with open(path_file + type_file, 'r', encoding='utf8') as content:
+        return content.read()
+
+
+def read_lines_file(
+        path_file: str,
+        type_file: str = '') -> list:
+    with open(path_file + type_file, 'r', encoding='utf8') as content:
+        return content.readlines()
+
+
+def write_lines_file(
+        content: list,
+        path_file: str,
+        type_file: str = '',
+        mode: str = 'w') -> list:
+    with open(path_file + type_file, mode) as outfile:
+        outfile.writelines(content)
+
+
+# TODO: This method will be removed in the future.
 def get_content(path_file: str, separator: str):
     """Get the contents of a file.
 
@@ -26,7 +56,7 @@ def get_content(path_file: str, separator: str):
         for index, value in enumerate(item):
             if value == separator:
                 info_name = item[0:index].lower().replace('|', '')
-                info_value = item[index+1:len(item)] \
+                info_value = item[index + 1:len(item)] \
                     .replace('"', '').replace('|', ' ')
 
                 if info_value[0] == ' ':
@@ -35,61 +65,3 @@ def get_content(path_file: str, separator: str):
                 my_info.update({info_name: info_value})
 
     return my_info
-
-
-def write_file(
-        content: str,
-        path_file: str,
-        type_file: str = '',
-        mode: str = 'w') -> str:
-    with open(path_file + type_file, mode) as outfile:
-        outfile.write(content)
-
-
-def read_file(path_file: str, type_file: str = '') -> str:
-    with open(path_file + type_file, 'r', encoding='utf8') as content:
-        content = content.read()
-    return content
-
-
-def get_system() -> dict:
-    """Get System Information
-
-    Returns
-    -------
-    dict
-        Dictionary with contents of the .hostnamectl file.
-    """
-    file_system = popen('hostnamectl').read()
-    content = get_content(path_file=file_system, separator=":")
-
-    return {
-        "id": "index",
-        "kernel": content.get('kernel'),
-        "static_host_name": content.get('statichostname'),
-        "hardware_vendor": content.get('hardwarevendor'),
-        "hardware_model": content.get('hardwaremodel'),
-        "architecture": content.get('architecture'),
-        "icon_name": content.get('iconname'),
-        "chassis": content.get('chassis')
-    }
-
-
-def get_distro() -> dict:
-    """Get Linux distribution
-
-    Returns
-    -------
-    dict
-        Dictionary with contents of the .os-release file.
-    """
-    file_distro = popen('cat /etc/os-release').read()
-    content = get_content(path_file=file_distro, separator="=")
-
-    return {
-        "id": "index",
-        "name": content.get('name'),
-        "pretty_name": content.get('pretty_name'),
-        "version_id": content.get('version_id'),
-        "version": content.get('version'),
-    }
